
// $Id: AlienCommand.cpp,v 1.14 2012/11/29 17:06:24 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "AlienCommand.h"
#include "FileInfo.h"

//___________________________________________________________________
unsigned int& AlienCommand::_counter( void )
{
    static unsigned int counter( 0 );
    return counter;
}

//___________________________________________________________________
AlienCommand::AlienCommand( const Type type ):
    Counter( "AlienCommand" ),
    id_( _counter()++ ),
    type_( type )
{}

//___________________________________________________________________
QString AlienCommand::name( const Type& type )
{
    if( _names().empty() ) _initializeNames();
    NameMap::const_iterator iter( _names().find( type ) );
    return iter != _names().end() ? iter.value():"";
}

//___________________________________________________________________
QString AlienCommand::errorString( void ) const
{

    switch( type() )
    {

        case AlienCommand::CheckProxy:
        return "No valid GSI proxy was found. "
            "All connections to the grid are likely to fail. "
            "Use <xrdgsiproxy init> to get a valid proxy.";

        case AlienCommand::Connect:
        return "Failed to connect to remote file system.";

        case AlienCommand::HomeDirectory:
        {
            const FileInfo& path( argument(0) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to query "
                << (path.isLocal() ? "local ":"remote ")
                << "home folder.";
            return buffer;
        }

        case AlienCommand::ShowDirectory:
        {

            const FileInfo& path( argument(0) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to query content of "
                << ( path.isLocal() ? "local ":"remote " )
                << " folder '" << path.file() << "'.";
            return buffer;
        }

        case AlienCommand::CreateDirectory:
        {

            const FileInfo& path( argument(0) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to create "
                << ( path.isLocal() ? "local ":"remote " )
                << " folder '" << path.file() << "'";
            return buffer;

        }

        case AlienCommand::Rename:
        {

            const FileInfo& path( argument(0) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to rename "
                << ( path.isLocal() ? "local ":"remote ")
                << ( path.isFolder() ? "folder '":"file " )
                << "'" << path.file() << "'";
            return buffer;

        }

        case AlienCommand::Remove:
        {

            const FileInfo& path( argument(0) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to remove "
                << ( path.isLocal() ? "local ":"remote ")
                << ( path.isFolder() ? "folder '":"file " )
                << "," << path << "'";
            return buffer;

        }

        case AlienCommand::Copy:
        {
            const FileInfo& source( argument(0) );
            const FileInfo& destination( argument(1) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to copy "
                << ( source.isLocal() ? "local ":"remote ")
                << ( source.isFolder() ? "folder '":"file '" )
                << source.file() << "' "
                << "to "
                << ( destination.isLocal() ? "local ":"remote ")
                << "folder '" << (destination.isFolder() ? destination.file():destination.path() ) << "'";
            return buffer;
        }

        case AlienCommand::Open:
        {

            const FileInfo& path( argument(0) );
            QString buffer;
            QTextStream( &buffer )
                << "Failed to open "
                << ( path.isLocal() ? "local ":"remote ")
                << " file '" << path << "'";
            return buffer;

        }

        default: return QString();
    }

}

//___________________________________________________________________
void AlienCommand::_initializeNames( void )
{
    _names()[None] = "none";
    _names()[Connect] = "connect";
    _names()[CheckProxy] = "check GSI proxy validity";
    _names()[FlushErrors] = "check failed commands (recursive)";
    _names()[HomeDirectory]="query home directory";
    _names()[ShowDirectory]="query directory content";
    _names()[CreateDirectory]="create directory";
    _names()[Copy]="copy selected files";
    _names()[Locate]="locate selected files";
    _names()[Rename]="rename selected file";
    _names()[Remove]="remove selected files";
    _names()[Open]="open selected files";
    _names()[Find]="find files collection";
}

//___________________________________________________________________
AlienCommand::NameMap& AlienCommand::_names( void )
{
    static NameMap names;
    return names;
}
