
// $Id: AlienCommandDialog.cpp,v 1.9 2012/10/11 18:41:55 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/


#include "AlienCommandDialog.h"

#include "AlienCommandModel.h"
#include "AlienMacroModel.h"
#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "Icons.h"
#include "IconEngine.h"
#include "IconSize.h"
#include "TreeView.h"

#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QShortcut>
#include <QtGui/QSplitter>

//__________________________________________________
AlienCommandDialog::AlienCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton ),
    macroModel_( 0 ),
    commandModel_( 0 )
{

    Debug::Throw( "AlienCommandDialog::AlienCommandDialog.\n" );
    setWindowTitle( "Command List - Gridwatch" );
    setOptionName( "ALIEN_COMMAND_DIALOG" );

    // customize layout
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    QSplitter* splitter;
    mainLayout().addWidget( splitter = new QSplitter( this ) );
    splitter->setOrientation( Qt::Vertical );

    // macros
    {

        QWidget* container = new QWidget();
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->setMargin(0);
        container->layout()->setSpacing(2);
        container->layout()->addWidget( new QLabel( " Macros:", container ) );
        container->layout()->addWidget( macroList_ = new TreeView(container) );

        macroList_->header()->hide();
        macroList_->setSortingEnabled( true );
        macroList_->setIconSize( IconSize( IconSize::Medium ) );
        macroList_->setSelectionMode( TreeView::ContiguousSelection );
        macroList_->setModel( &macroModel_ );
        macroList_->setOptionName( "ALIEN_MACRO_LIST" );

        QMenu* menu( new ContextMenu( macroList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, macroList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, macroList_ ) );

    }

    // commands
    {
        QWidget* container = new QWidget();
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->setMargin(0);
        container->layout()->setSpacing(2);
        container->layout()->addWidget( new QLabel( " Commands:", container ) );
        container->layout()->addWidget( commandList_ = new TreeView(container) );

        commandList_->header()->hide();
        commandList_->setSortingEnabled( true );
        commandList_->setIconSize( IconSize( IconSize::Medium ) );
        commandList_->setSelectionMode( TreeView::ContiguousSelection );
        commandList_->setModel( &commandModel_ );
        commandList_->setOptionName( "ALIEN_COMMAND_LIST" );

        QMenu* menu( new ContextMenu( commandList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, commandList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, commandList_ ) );

    }

    // ok button
    connect( &okButton(), SIGNAL( pressed( void ) ), SLOT( close( void ) ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//_____________________________________________________________
void AlienCommandDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "AlienCommandDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
