// $Id: Application.cpp,v 1.43 2012/11/29 17:06:24 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Application.h"

#include "ProgressStatusBar.h"
#include "Config.h"
#include "ConfigurationDialog.h"
#include "FileSelectionFrame.h"
#include "Icons.h"
#include "IconEngine.h"
#include "MainWindow.h"
#include "QuestionDialog.h"
#include "ScratchFileMonitor.h"
#include "TreeView.h"
#include "Util.h"
#include "XmlOptions.h"

#include <QtGui/QApplication>

//____________________________________________
void Application::usage( void )
{
    Debug::Throw(0) << "usage : gridftp [options] [path]" << endl;
    SERVER::ApplicationManager::commandLineParser().usage();
    return;
}

//____________________________________________
Application::Application( CommandLineArguments arguments ):
    BaseApplication( 0, arguments ),
    Counter( "Application" ),
    mainWindow_( 0 )
{ Debug::Throw( "Application::Application.\n" ); }

//____________________________________________
Application::~Application( void )
{}

//____________________________________________
void Application::initApplicationManager( void )
{
    Debug::Throw( "Application::initApplicationManager.\n" );

    // retrieve files from arguments and expand if needed
    CommandLineParser parser( SERVER::ApplicationManager::commandLineParser( _arguments() ) );
    QStringList& orphans( parser.orphans() );
    for( QStringList::iterator iter = orphans.begin(); iter != orphans.end(); ++iter )
    { if( !iter->isEmpty() ) (*iter) = File( *iter ).expand(); }

    // replace arguments
    _setArguments( parser.arguments() );

    // base class initialization
    BaseApplication::initApplicationManager();

}

//____________________________________________
bool Application::realizeWidget( void )
{
    Debug::Throw( "Application::realizeWidget.\n" );

    // check if the method has already been called.
    if( !BaseApplication::realizeWidget() ) return false;

    // actions
    _installActions();

    // top widget
    mainWindow_ = new MainWindow();
    mainWindow_->setWindowTitle( "Gridftp" );

    // scratch files
    scratchFileMonitor_ = new ScratchFileMonitor( this );
    connect( qApp, SIGNAL( aboutToQuit( void ) ), scratchFileMonitor_, SLOT( deleteScratchFiles( void ) ) );
    connect( &mainWindow(), SIGNAL( scratchFileCreated( const File& ) ), scratchFileMonitor_, SLOT( add( const File& ) ) );

    // show main window
    mainWindow_->centerOnDesktop();
    mainWindow_->show();

    // parse arguments
    QStringList filenames( SERVER::ApplicationManager::commandLineParser( _arguments() ).orphans() );
    if( !filenames.isEmpty() ) mainWindow_->initialize( File( filenames.front() ).expand() );
    else mainWindow_->initialize();

    // configuration
    emit configurationChanged();

    return true;

}

//___________________________________________________________
void Application::_configuration( void )
{
    Debug::Throw( "Application::_configuration.\n" );
    emit saveConfiguration();
    ConfigurationDialog dialog;
    connect( &dialog, SIGNAL( configurationChanged() ), SIGNAL( configurationChanged() ) );
    dialog.centerOnWidget( qApp->activeWindow() );
    dialog.exec();
}

//___________________________________________________________
void Application::_installActions( void )
{

    Debug::Throw( "Application::_installActions.\n" );

    // rename about action
    aboutAction().setText( "About Gridftp" );
    configurationAction().setText( "Configure Gridftp..." );

}
