/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "CopyFilesDialog.h"

#include "BaseIcons.h"
#include "IconEngine.h"
#include "TreeView.h"
#include "XmlOptions.h"

#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QLayout>
#include <QtGui/QScrollBar>

//____________________________________________________________________________
CopyFilesDialog::CopyFilesDialog( QWidget* parent, const FileInfo::List& files, const File& destination ):
    QuestionDialog( parent ),
    model_( this )
{

    Debug::Throw( "CopyFilesDialog::CopyFilesDialog.\n" );

    // option name
    setOptionName( "COPY_FILES_DIALOG" );

    // customize buttons
    okButton().setText( "Copy" );
    okButton().setIcon( IconEngine::get( ICONS::COPY ) );

    // label
    QString buffer;
    QTextStream( &buffer )
        << "Copy " << files.description( FileInfo::List::LowerCase )
        << " to folder " << destination;
    setText( buffer );

    TreeView* treeView( new TreeView( this ) );
    treeView->setSelectionMode( QAbstractItemView::NoSelection );

    model_.setShowIcons( false );
    model_.add( files );
    model_.sort( FileInfoModel::FILE, Qt::DescendingOrder );

    // setup list
    treeView->setModel( &model_ );
    treeView->toggleShowHeader( false );
    treeView->setMask( 1<<FileInfoModel::FILE );
    treeView->header()->setSortIndicator( FileInfoModel::FILE, Qt::AscendingOrder );

    // resize list to accomodate longest item
    int maxWidth( 0 );
    foreach( const FileInfo& fileInfo, files )
    { maxWidth = qMax( maxWidth, treeView->fontMetrics().width( fileInfo.file() ) ); }

    treeView->verticalScrollBar()->adjustSize();
    treeView->setMinimumSize( QSize(
        maxWidth + treeView->verticalScrollBar()->width() + 10,
        treeView->fontMetrics().height() + 10 ) );

    setDetails( treeView );

}
