#ifndef DefaultOptions_h
#define DefaultOptions_h

// $Id: DefaultOptions.h,v 1.21 2012/12/08 20:12:01 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA	02111-1307 USA
*
*
*******************************************************************************/

#include "AlienCommandModel.h"
#include "AlienMacroModel.h"
#include "FileInfoModel.h"
#include "FileSelectionFrame.h"
#include "Util.h"
#include "XmlOptions.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().keep( "APPLICATIONS" );
    XmlOptions::get().keep( "COLLECTION_SEARCH_STRING" );

    XmlOptions::get().keep( "ICON_PIXMAP" );
    XmlOptions::get().add( "ICON_PIXMAP", Option( ":/icon.png" , "application icon", Option::None ) );
    XmlOptions::get().add( "ICON_PIXMAP", Option( ":/icon-large.png" , "application icon", Option::None ) );

    // customize pixmap paths
    XmlOptions::get().keep( "PIXMAP_PATH" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/128x128" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/48x48" );

    XmlOptions::get().set( "DB_SIZE", "30" );
    XmlOptions::get().set( "MAIN_WINDOW_HEIGHT", "500" );
    XmlOptions::get().set( "MAIN_WINDOW_WIDTH", "700" );

    XmlOptions::get().set( "LOG_ENABLED", "1" );
    XmlOptions::get().set( "SHOW_COMMAND_LIST", "0" );
    XmlOptions::get().set( "SHOW_LOG", "0" );
    XmlOptions::get().set( "SHOW_HIDDEN_FILES", "0" );
    XmlOptions::get().set( "SHOW_TOOLTIPS", "0" );
    XmlOptions::get().set( "RESTORE_SESSION", "1" );

    XmlOptions::get().set( "USE_PREFIX", "1" );
    XmlOptions::get().set( "USE_TRUNCATION", "1" );
    XmlOptions::get().set( "SHOW_NAVIGATOR", "1" );

    // Alien connection
    XmlOptions::get().set( "ALIEN_HOST", "pcapiserv03.cern.ch" );
    XmlOptions::get().set( "ALIEN_PORT", "10000" );

    // view mode
    XmlOptions::get().set<unsigned int>( "LOCAL_VIEW_MODE", FileSelectionFrame::ICONS );
    XmlOptions::get().set<unsigned int>( "REMOTE_VIEW_MODE", FileSelectionFrame::ICONS );

    // list mask
    XmlOptions::get().set<unsigned int>( "LOCAL_LIST_MASK", (1<<FileInfoModel::FILE) | (1<<FileInfoModel::SIZE) );
    XmlOptions::get().set<unsigned int>( "REMOTE_LIST_MASK", (1<<FileInfoModel::FILE) | (1<<FileInfoModel::SIZE) );
    XmlOptions::get().set<unsigned int>( "LOCAL_LIST_SORT_ORDER", 0 );
    XmlOptions::get().set<unsigned int>( "REMOTE_LIST_SORT_ORDER", 0 );

    // application name
    XmlOptions::get().set( "APP_NAME", "GRIDFTP" );

    // certificates path
    XmlOptions::get().set( "CERTIFICATES_PATH", Util::env( "XrdSecSSLCADIR" ) );

    // command list
    XmlOptions::get().set( "ALIEN_COMMAND_LIST_MASK", Option().set<int>( 1<<AlienCommandModel::NAME ) );
    XmlOptions::get().set( "ALIEN_MACRO_LIST_MASK", Option().set<int>( 1<<AlienMacroModel::NAME ) );

    // pixmap size
    XmlOptions::get().set( "ICON_VIEW_PIXMAP_SIZE", 48 );

    // database file
    XmlOptions::get().set( "HELP_FILE", File( "/.gridftp_help" ).addPath( Util::home() ) );
    XmlOptions::get().set( "RC_FILE", File(".gridftprc").addPath( Util::home() ) );
    XmlOptions::get().setAutoDefault( false );

};

#endif
