// $Id: FileIconProvider.cpp,v 1.7 2012/12/10 22:28:30 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "FileIconProvider.h"

#include "CustomPixmap.h"
#include "Icons.h"
#include "IconEngine.h"

//__________________________________________________________________
FileIconProvider::FileIconProvider( QObject* parent ):
    BaseFileIconProvider( parent )
{ mimeTypeIconProvider_.insert( "jdl", "application-x-shellscript.png" ); }

//__________________________________________________________________
const QIcon& FileIconProvider::icon( const BaseFileInfo& fileInfo )
{

    // try from base class
    const QIcon& icon( BaseFileIconProvider::icon( fileInfo ) );
    if( !icon.isNull() ) return icon;

    // get relevant file info type
    int type( fileInfo.type() );
    if( type & BaseFileInfo::Navigator ) type = BaseFileInfo::Navigator;
    else type &= BaseFileInfo::Document|BaseFileInfo::Folder|BaseFileInfo::Link|BaseFileInfo::Hidden;

    // build key
    Key key( fileInfo.file().extension(), type );

    // check if already created
    IconCache::const_iterator iter( icons_.find( key ) );
    if( iter != icons_.end() ) return iter.value();

    // create
    QIcon base;
    if( type & BaseFileInfo::Navigator ) base = IconEngine::get( ICONS::PARENT );
    else if( type & BaseFileInfo::Folder ) base = IconEngine::get( ICONS::FOLDER );
    else if( type & BaseFileInfo::Document )
    {

        // try get icon from mimetypes
        base = mimeTypeIconProvider_.icon( fileInfo.file().extension() );
        if( base.isNull() ) base = IconEngine::get( ICONS::DOCUMENT );

    }

    // add link overlay
    if( type & BaseFileInfo::Link )
    {

        QIcon copy( base );
        base = QIcon();
        QIcon linkOverlay( IconEngine::get( ICONS::LINK ) );
        foreach( const QSize& size, copy.availableSizes() )
        {

            QSize overlaySize;
            if( size.width() <= 16 ) overlaySize = QSize( 8, 8 );
            else if( size.width() <= 22 ) overlaySize = QSize( 8, 8 );
            else if( size.width() <= 32 ) overlaySize = QSize( 12, 12 );
            else if( size.width() <= 48 ) overlaySize = QSize( 16, 16 );
            else if( size.width() <= 64 ) overlaySize = QSize( 22, 22 );
            else if( size.width() <= 128 ) overlaySize = QSize( 48, 48 );
            else overlaySize = QSize( 64, 64 );

            base.addPixmap( CustomPixmap( copy.pixmap( size ) ).merge( linkOverlay.pixmap( overlaySize ), CustomPixmap::BOTTOM_RIGHT ) );
        }
    }

    // hidden file
    if( type & BaseFileInfo::Hidden )
    {
        QIcon copy( base );
        base = QIcon();
        foreach( const QSize& size, copy.availableSizes() )
        { base.addPixmap( CustomPixmap( copy.pixmap( size ) ).transparent( 0.6 ) ); }

    }

    // insert in map and return
    return icons_.insert( key, base ).value();

}
