#ifndef FindCollectionDialog_h
#define FindCollectionDialog_h

// $Id: FindCollectionDialog.h,v 1.4 2012/10/05 11:55:26 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "AlienMacro.h"
#include "CustomComboBox.h"
#include "CustomDialog.h"
#include "File.h"
#include "TextEditor.h"

#include <QtGui/QComboBox>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>

//! QDialog used to commit selected files
class FindCollectionDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! constructor
    FindCollectionDialog( QWidget* = 0 );

    //! destructor
    virtual ~FindCollectionDialog( void )
    {}

    //! set path
    void setPath( const File& value )
    { path_ = value; }

    //! pattern
    void setPattern( const QString& value )
    { patternComboBox_->setEditText( value ); }

    //! set default filename
    void setDefaultFilename( const File& value )
    { filename_ = value; }

    signals:

    //! request command
    void macroRequested( const AlienMacro& );

    public slots:

    //! process collection
    void processCollection( const QString& );

    protected slots:

    //! request collection update
    void _requestUpdate( void );

    //! save collection
    void _save( void );

    //! update buttons
    void _updateButtons( void );

    private:

    //! path
    File path_;

    //! file name
    File filename_;

    //! pattern editor
    CustomComboBox* patternComboBox_;

    //! collection type (flat | Xml)
    QComboBox* comboBox_;

    //! collection editor
    TextEditor* editor_;

    //! update button
    QPushButton* findButton_;

    //! save button
    QPushButton* saveButton_;

    //! status label
    QLabel* statusLabel_;

};

#endif
