// $Id: LogDialog.cpp,v 1.4 2012/10/22 11:40:47 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "LogDialog.h"

#include "Debug.h"
#include "Icons.h"
#include "IconEngine.h"
#include "LogWidget.h"

#include <QtGui/QShortcut>

//_____________________________________________________________
LogDialog::LogDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{
    Debug::Throw("LogDialog::LogDialog.\n" );
    setWindowTitle( "Log Information - Gridftp" );
    setOptionName( "LOG_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    // editor
    editor_ = new LogWidget( this );
    editor_->setOptionName( "LOG_WIDGET" );
    mainLayout().addWidget( editor_ );

    // clear button
    QPushButton *button = new QPushButton( IconEngine::get( ICONS::CLEAR ), "Clear", this );
    connect( button, SIGNAL( clicked() ), editor_, SLOT( clear() ) );
    buttonLayout().insertWidget(1, button );

    // ok button
    connect( &okButton(), SIGNAL( pressed( void ) ), SLOT( close( void ) ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//_____________________________________________________________
void LogDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "LogDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
