// $Id: Menu.cpp,v 1.16 2012/12/12 10:37:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Menu.h"

#include "Debug.h"
#include "DebugMenu.h"
#include "DockWidget.h"
#include "Application.h"
#include "FileSelectionFrame.h"
#include "Icons.h"
#include "IconEngine.h"
#include "MainWindow.h"
#include "Singleton.h"
#include "ViewModeMenu.h"
#include "XmlOptions.h"

#include <QtGui/QMenu>

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu\n" );

    // generic menu
    QMenu *menu;

    // application and top widget
    Application& application( *static_cast<Application*>(Singleton::get().application()) );
    MainWindow& mainwindow( *static_cast<MainWindow*>( window() ) );

    // file menu
    menu = addMenu( "File" );
    menu->addAction( &mainwindow.connectAction() );
    menu->addAction( &application.closeAction() );

    menu = addMenu( "View" );
    menu->addMenu( viewModeMenu_ = new ViewModeMenu( this ) );
    viewModeMenu_->setTitle( "View Mode" );
    menu->addSeparator();
    menu->addAction( &mainwindow.showHiddenFilesAction() );
    menu->addAction( &mainwindow.localSelectionFrame().visibilityAction() );
    menu->addAction( &mainwindow.placesPanel().visibilityAction() );
    menu->addSeparator();
    menu->addAction( &mainwindow.logAction() );
    menu->addAction( &mainwindow.commandDialogAction() );

    // Settings menu
    menu = addMenu( "Settings" );
    menu->addAction( &mainwindow.toggleLogAction() );
    menu->addSeparator();
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( "Help" );
    menu->addAction( &application.aboutQtAction() );
    menu->addAction( &application.aboutAction() );

    // debug menu
    #ifdef DEBUG
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( this ) );
    debugMenu->setTitle( "Debug" );
    menu->addMenu( debugMenu );
    #endif

}
