/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "NewFolderDialog.h"

#include "LineEditor.h"
#include "XmlOptions.h"

#include <QtGui/QLabel>
#include <QtGui/QLayout>

//____________________________________________________________________________
NewFolderDialog::NewFolderDialog( QWidget* parent, const FileInfo& fileInfo ):
    CustomDialog( parent )
{

    Debug::Throw( "NewFolderDialog::NewFolderDialog.\n" );

    // option name
    setOptionName( "NEW_FOLDER_DIALOG" );

    // label
    QString buffer;
    QTextStream what( &buffer );
    what << "Create new folder in:\n" << fileInfo.file();
    QLabel* textLabel( new QLabel( buffer, this ) );
    mainLayout().addWidget( textLabel );

    // editor
    mainLayout().addWidget( editor_ = new LineEditor( this ) );
    textLabel->setBuddy( editor_ );

    // set text and selection
    editor().setText( fileInfo.isLocal() ? "New Folder":"Folder" );
    editor().setFocus();
    editor().selectAll();

    connect( editor_, SIGNAL( textChanged( const QString& ) ), SLOT( _updateButtons() ) );

    _updateButtons();

}

//____________________________________________________________________________
void NewFolderDialog::_updateButtons( void )
{ okButton().setEnabled( !editor().text().trimmed().isEmpty() ); }
