
// $Id: ViewModeMenu.cpp,v 1.1 2012/08/27 19:47:05 hpereira Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
****************************************************************************/

#include "ViewModeMenu.h"

#include "Application.h"
#include "Debug.h"
#include "FileSelectionFrame.h"
#include "MainWindow.h"

//_____________________________________________
ViewModeMenu::ViewModeMenu( QWidget* parent ):
QMenu( parent ),
Counter( "ViewModeMenu" )
{
    Debug::Throw( "ViewModeMenu::ViewModeMenu.\n" );
    actionGroup_ = new QActionGroup( this );
    connect( this, SIGNAL( aboutToShow() ), SLOT( _update() ) );
    connect( this, SIGNAL( triggered( QAction* ) ), SLOT( _selectViewMode( QAction* ) ) );
}

//_____________________________________________
void ViewModeMenu::_update( void )
{
    Debug::Throw( "ViewModeMenu::_update.\n" );

    // clear menu
    clear();
    actions_.clear();

    // retrieve current class from MainWindow
    MainWindow& window( *static_cast<MainWindow*>( parentWidget()->window()) );
    FileSelectionFrame::ViewMode viewMode( window.activeFrame().viewMode() );

    // insert actions
    {
        QAction* action = addAction( "Icons" );
        action->setCheckable( true );
        action->setChecked( viewMode == FileSelectionFrame::ICONS );
        actionGroup_->addAction( action );
        actions_.insert( action, FileSelectionFrame::ICONS );
    }

    // insert actions
    {
        QAction* action = addAction( "Details" );
        action->setCheckable( true );
        action->setChecked( viewMode == FileSelectionFrame::LIST );
        actionGroup_->addAction( action );
        actions_.insert( action, FileSelectionFrame::LIST );
    }

}

//_____________________________________________
void ViewModeMenu::_selectViewMode( QAction* action )
{
    Debug::Throw( "ViewModeMenu::_selectViewMode.\n" );
    ActionMap::iterator iter = actions_.find( action );
    if( iter != actions_.end() )
    { emit viewModeSelected( iter.value() ); }

    return;

}
