// $Id: main.cpp,v 1.1 2012/12/09 22:20:54 hupereir Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include <unistd.h>
#include <signal.h>

#include "Application.h"
#include "Debug.h"
#include "DefaultOptions.h"
#include "ErrorHandler.h"
#include "Singleton.h"
#include "SystemOptions.h"

//_______________________________
//! handles keyboard interuptions
void interrupt( int sig );

//__________________________________________
//! main function
int main (int argc, char *argv[])
{

    // Ensure proper cleaning at exit
    signal(SIGINT,  interrupt);
    signal(SIGTERM, interrupt);

    // error handler
    qInstallMsgHandler( ErrorHandler::Throw );

    // load possible command file
    CommandLineArguments arguments( argc, argv );
    if( SERVER::ApplicationManager::commandLineParser( arguments, false ).hasFlag( "--help" ) )
    {
        Application::usage();
        return 0;
    }

    // install additional options
    installDefaultOptions();
    installSystemOptions();
    XmlOptions::read( XmlOptions::get().raw( "RC_FILE" ) );

    // set debug level
    Debug::setLevel( XmlOptions::get().get<int>("DEBUG_LEVEL") );
    if( Debug::level() ) XmlOptions::get().print();

    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    QApplication application( argc, argv );
    application.setApplicationName( "Gridftp" );

    Application singleton( arguments );
    Singleton::get().setApplication( &singleton );
    singleton.initApplicationManager();

    application.exec();

    return 0;
}

//_____________________________________________
void interrupt( int sig )
{
    Debug::Throw() << "interrupt - Recieved signal " << sig << endl;
    qApp->quit();
}
